@@ -930,12 +930,17 @@ Wrapper for build_node, flips the node to UnManaged=>1 once it has been created
 
 sub build_unmanaged {
   my ($self,$ip,$DeleteIfExists,%args)=@_;
+
+  $self->log_info("Starting build_unmanaged");
   my $result=$self->build_node($ip,$DeleteIfExists,%args);
   return $result unless $result;
 
   my $nodeID=$result->get_data->{NodeID};
   my $target=$result;
-  $result=$self->UpdateNodeProps($nodeID,"UnManaged"=>JSON::true);
+
+  $result=$self->NodeUnmanage($nodeID);
+
+  $self->log_info("Finished build_unmanaged");
   return $result unless $result;
 
   return $target;
